==> universal_html-1.1.10.tar.gz: lib/src/html/api/data_transfer.dart <==
// Copyright 2019 terrier989@gmail.com
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
/*
Some source code in this file was adopted from 'dart:html' in Dart SDK. See:
  https://github.com/dart-lang/sdk/tree/master/tools/dom

The source code adopted from 'dart:html' had the following license:

  Copyright 2012, the Dart project authors. All rights reserved.
  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are
  met:
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above
      copyright notice, this list of conditions and the following
      disclaimer in the documentation and/or other materials provided
      with the distribution.
    * Neither the name of Google Inc. nor the names of its
      contributors may be used to endorse or promote products derived
      from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

part of universal_html.internal;

abstract class DataTransfer {
  String dropEffect;
  String effectAllowed;

  List<File> get files;

  DataTransferItemList get items;

  List<String> get types;

  void clearData([String format]);

  String getData(String format);

  void setData(String format, String data);

  void setDragImage(Element image, int x, int y);
}

abstract class DataTransferItem {
  DataTransferItem._();

  String get kind;

  String get type;

  Entry getAsEntry();

  File getAsFile();
}

abstract class DataTransferItemList {
  DataTransferItemList._();

  int get length {
    throw UnimplementedError();
  }

  DataTransferItem operator [](int index) {
    throw UnimplementedError();
  }

  DataTransferItem add(dynamic data_OR_file, [String type]) {
    throw UnimplementedError();
  }

  DataTransferItem addData(String data, String type) {
    throw UnimplementedError();
  }

  DataTransferItem addFile(File file) {
    throw UnimplementedError();
  }

  void clear() {
    throw UnimplementedError();
  }

  DataTransferItem item(int index) {
    throw UnimplementedError();
  }

  void remove(int index) {
    throw UnimplementedError();
  }
}

==> universal_html-2.0.1.tar.gz: lib/src/html/api/data_transfer.dart <==
// Copyright 2019 terrier989@gmail.com
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
/*
Some source code in this file was adopted from 'dart:html' in Dart SDK. See:
  https://github.com/dart-lang/sdk/tree/master/tools/dom

The source code adopted from 'dart:html' had the following license:

  Copyright 2012, the Dart project authors. All rights reserved.
  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are
  met:
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above
      copyright notice, this list of conditions and the following
      disclaimer in the documentation and/or other materials provided
      with the distribution.
    * Neither the name of Google Inc. nor the names of its
      contributors may be used to endorse or promote products derived
      from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

part of universal_html.internal;

abstract class DataTransfer {
  String? dropEffect;
  String? effectAllowed;

  List<File> get files;

  DataTransferItemList get items;

  List<String> get types;

  void clearData([String format]);

  String getData(String format);

  void setData(String format, String data);

  void setDragImage(Element image, int x, int y);
}

abstract class DataTransferItem {
  DataTransferItem._();

  String get kind;

  String get type;

  Entry getAsEntry();

  File getAsFile();
}

abstract class DataTransferItemList {
  DataTransferItemList._();

  int get length {
    throw UnimplementedError();
  }

  DataTransferItem operator [](int index) {
    throw UnimplementedError();
  }

  DataTransferItem add(dynamic data_OR_file, [String? type]) {
    throw UnimplementedError();
  }

  DataTransferItem addData(String data, String type) {
    throw UnimplementedError();
  }

  DataTransferItem addFile(File file) {
    throw UnimplementedError();
  }

  void clear() {
    throw UnimplementedError();
  }

  DataTransferItem item(int index) {
    throw UnimplementedError();
  }

  void remove(int index) {
    throw UnimplementedError();
  }
}
